@@ -1,44 +1,41 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  label-barcode.c
+ *  Copyright (C) 2001-2009  Jim Evins <evins@snaught.com>.
  *
- *  label_barcode.c:  GLabels label text object
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2001-2007  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
+
 #include "label-barcode.h"
 
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <glib/gmem.h>
-#include <glib/gstrfuncs.h>
-#include <glib/gmessages.h>
-#include <cairo.h>
 #include <pango/pangocairo.h>
 
 #include "debug.h"
 
+
 /*========================================================*/
 /* Private macros and constants.                          */
 /*========================================================*/
 
 #define FONT_SCALE (72.0/96.0)
 
+
 /*========================================================*/
 /* Private types.                                         */
 /*========================================================*/
@@ -52,10 +49,12 @@ struct _glLabelBarcodePrivate {
 	guint           format_digits;
 };
 
+
 /*========================================================*/
 /* Private globals.                                       */
 /*========================================================*/
 
+
 /*========================================================*/
 /* Private function prototypes.                           */
 /*========================================================*/
@@ -70,22 +69,28 @@ static void  get_size                       (glLabelObject       *object,
 					     gdouble             *h);
 
 static void  set_line_color                 (glLabelObject       *object,
-					     glColorNode         *line_color);
+					     glColorNode         *line_color,
+                                             gboolean             checkpoint);
 
 static glColorNode *get_line_color          (glLabelObject       *object);
 
-static void    draw_object                (glLabelObject     *object,
-                                           cairo_t           *cr,
-                                           gboolean           screen_flag,
-                                           glMergeRecord     *record);
+static void     draw_object                 (glLabelObject       *object,
+                                             cairo_t             *cr,
+                                             gboolean             screen_flag,
+                                             glMergeRecord       *record);
+
+static gboolean object_at                   (glLabelObject       *object,
+                                             cairo_t             *cr,
+                                             gdouble              x_pixels,
+                                             gdouble              y_pixels);
 
 
-
 /*****************************************************************************/
 /* Boilerplate object stuff.                                                 */
 /*****************************************************************************/
 G_DEFINE_TYPE (glLabelBarcode, gl_label_barcode, GL_TYPE_LABEL_OBJECT);
 
+
 static void
 gl_label_barcode_class_init (glLabelBarcodeClass *class)
 {
@@ -100,18 +105,20 @@ gl_label_barcode_class_init (glLabelBarcodeClass *class)
 	label_object_class->get_line_color = get_line_color;
         label_object_class->draw_object    = draw_object;
         label_object_class->draw_shadow    = NULL;
+        label_object_class->object_at      = object_at;
 
 	object_class->finalize = gl_label_barcode_finalize;
 }
 
+
 static void
 gl_label_barcode_init (glLabelBarcode *lbc)
 {
 	lbc->priv = g_new0 (glLabelBarcodePrivate, 1);
-	lbc->priv->color_node = gl_color_node_new_default ();
 	lbc->priv->text_node  = gl_text_node_new_from_text ("");
 }
 
+
 static void
 gl_label_barcode_finalize (GObject *object)
 {
@@ -127,21 +134,40 @@ gl_label_barcode_finalize (GObject *object)
 	G_OBJECT_CLASS (gl_label_barcode_parent_class)->finalize (object);
 }
 
+
 /*****************************************************************************/
 /* NEW label "barcode" object.                                               */
 /*****************************************************************************/
 GObject *
-gl_label_barcode_new (glLabel *label)
+gl_label_barcode_new (glLabel *label,
+                      gboolean checkpoint)
 {
-	glLabelBarcode *lbc;
+	glLabelBarcode      *lbc;
+	glColorNode         *line_color_node;
 
 	lbc = g_object_new (gl_label_barcode_get_type(), NULL);
 
-	gl_label_object_set_parent (GL_LABEL_OBJECT(lbc), label);
+        if (label != NULL)
+        {
+                if ( checkpoint )
+                {
+                        gl_label_checkpoint (label, _("Create barcode object"));
+                }
+
+                line_color_node = gl_color_node_new_default ();
+
+                line_color_node->color = gl_label_get_default_line_color(label);
+
+                lbc->priv->color_node = line_color_node;
+
+                gl_label_add_object (label, GL_LABEL_OBJECT (lbc));
+                gl_label_object_set_parent (GL_LABEL_OBJECT (lbc), label);
+        }
 
 	return G_OBJECT (lbc);
 }
 
+
 /*****************************************************************************/
 /* Copy object contents.                                                     */
 /*****************************************************************************/
@@ -167,9 +193,9 @@ copy (glLabelObject *dst_object,
 	gl_label_barcode_get_props (lbc, &id, &text_flag, &checksum_flag, &format_digits);
 	color_node = get_line_color (src_object);
 
-	gl_label_barcode_set_data (new_lbc, text_node);
-	gl_label_barcode_set_props (new_lbc, id, text_flag, checksum_flag, format_digits);
-	set_line_color (dst_object, color_node);
+	gl_label_barcode_set_data (new_lbc, text_node, FALSE);
+	gl_label_barcode_set_props (new_lbc, id, text_flag, checksum_flag, format_digits, FALSE);
+	set_line_color (dst_object, color_node, FALSE);
 
 	gl_color_node_free (&color_node);
 	gl_text_node_free (&text_node);
@@ -184,40 +210,58 @@ copy (glLabelObject *dst_object,
 /*****************************************************************************/
 void
 gl_label_barcode_set_data (glLabelBarcode *lbc,
-			   glTextNode     *text_node)
+			   glTextNode     *text_node,
+                           gboolean        checkpoint)
 {
+        glLabel *label;
+
 	gl_debug (DEBUG_LABEL, "START");
 
 	g_return_if_fail (lbc && GL_IS_LABEL_BARCODE (lbc));
 
-	if (!gl_text_node_equal (lbc->priv->text_node, text_node)) {
-
+	if (!gl_text_node_equal (lbc->priv->text_node, text_node))
+        {
+                if ( checkpoint )
+                {
+                        label = gl_label_object_get_parent (GL_LABEL_OBJECT (lbc));
+                        gl_label_checkpoint (label, _("Barcode data"));
+                }
+                
 		gl_text_node_free (&lbc->priv->text_node);
 		lbc->priv->text_node = gl_text_node_dup (text_node);
 
 		gl_label_object_emit_changed (GL_LABEL_OBJECT(lbc));
-
 	}
 
 	gl_debug (DEBUG_LABEL, "END");
 }
 
+
 void
 gl_label_barcode_set_props (glLabelBarcode *lbc,
 			    gchar          *id,
 			    gboolean        text_flag,
 			    gboolean        checksum_flag,
-			    guint           format_digits)
+			    guint           format_digits,
+                            gboolean        checkpoint)
 {
+        glLabel *label;
+
 	gl_debug (DEBUG_LABEL, "START");
 
 	g_return_if_fail (lbc && GL_IS_LABEL_BARCODE (lbc));
 
 	if ( ((lbc->priv->id == NULL) && (id != NULL))
-	     || (g_strcasecmp (lbc->priv->id, id) != 0)
+	     || ((lbc->priv->id != NULL) && (id != NULL) && (g_ascii_strcasecmp (lbc->priv->id, id) != 0))
 	     || (lbc->priv->text_flag != text_flag)
 	     || (lbc->priv->checksum_flag != checksum_flag)
-	     || (lbc->priv->format_digits != format_digits)) {
+	     || (lbc->priv->format_digits != format_digits))
+        {
+                if ( checkpoint )
+                {
+                        label = gl_label_object_get_parent (GL_LABEL_OBJECT (lbc));
+                        gl_label_checkpoint (label, _("Barcode property"));
+                }
 
 		lbc->priv->id               = g_strdup (id);
 		lbc->priv->text_flag        = text_flag;
@@ -225,7 +269,6 @@ gl_label_barcode_set_props (glLabelBarcode *lbc,
 		lbc->priv->format_digits    = format_digits;
 
 		gl_label_object_emit_changed (GL_LABEL_OBJECT(lbc));
-
 	}
 
 	gl_debug (DEBUG_LABEL, "END");
@@ -243,6 +286,7 @@ gl_label_barcode_get_data (glLabelBarcode *lbc)
 	return gl_text_node_dup (lbc->priv->text_node);
 }
 
+
 void
 gl_label_barcode_get_props (glLabelBarcode *lbc,
 			    gchar          **id,
@@ -258,6 +302,7 @@ gl_label_barcode_get_props (glLabelBarcode *lbc,
 	*format_digits    = lbc->priv->format_digits;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* PRIVATE.  Get object size method.                                         */
 /*---------------------------------------------------------------------------*/
@@ -322,25 +367,35 @@ get_size (glLabelObject *object,
 	gl_debug (DEBUG_LABEL, "END");
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* PRIVATE.  Set line color method.                                          */
 /*---------------------------------------------------------------------------*/
 static void
 set_line_color (glLabelObject *object,
-		glColorNode   *line_color_node)
+		glColorNode   *line_color_node,
+                gboolean       checkpoint)
 {
 	glLabelBarcode *lbarcode = (glLabelBarcode *)object;
+        glLabel        *label;
 
 	g_return_if_fail (lbarcode && GL_IS_LABEL_BARCODE (lbarcode));
 
-	if ( !gl_color_node_equal(lbarcode->priv->color_node, line_color_node) ) {
-		
+	if ( !gl_color_node_equal(lbarcode->priv->color_node, line_color_node) )
+        {
+                if ( checkpoint )
+                {
+                        label = gl_label_object_get_parent (GL_LABEL_OBJECT (lbarcode));
+                        gl_label_checkpoint (label, _("Barcode data"));
+                }
+
 		gl_color_node_free (&(lbarcode->priv->color_node));
 		lbarcode->priv->color_node = gl_color_node_dup (line_color_node);
 		gl_label_object_emit_changed (GL_LABEL_OBJECT(lbarcode));
 	}
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* PRIVATE.  Get line color method.                                          */
 /*---------------------------------------------------------------------------*/
@@ -354,6 +409,7 @@ get_line_color (glLabelObject *object)
 	return gl_color_node_dup (lbarcode->priv->color_node);
 }
 
+
 /*****************************************************************************/
 /* Draw object method.                                                       */
 /*****************************************************************************/
@@ -363,24 +419,25 @@ draw_object (glLabelObject *object,
              gboolean       screen_flag,
              glMergeRecord *record)
 {
-        gdouble             x0, y0;
-        cairo_matrix_t      matrix;
-	glBarcode          *gbc;
-	glBarcodeLine      *line;
-	glBarcodeChar      *bchar;
-	GList              *li;
-	gdouble             y_offset;
-        PangoLayout        *layout;
+        gdouble               x0, y0;
+        cairo_matrix_t        matrix;
+        glBarcode            *gbc;
+        glBarcodeShape       *shape;
+        glBarcodeShapeLine   *line;
+        glBarcodeShapeAlpha  *bchar;
+        GList                *p;
+        gdouble               y_offset;
+        PangoLayout          *layout;
         PangoFontDescription *desc;
-	gchar              *text, *cstring;
-	glTextNode         *text_node;
-	gchar              *id;
-	gboolean            text_flag;
-	gboolean            checksum_flag;
-	guint               color;
-	glColorNode        *color_node;
-	guint               format_digits;
-	gdouble             w, h;
+        gchar                *text, *cstring;
+        glTextNode           *text_node;
+        gchar                *id;
+        gboolean              text_flag;
+        gboolean              checksum_flag;
+        guint                 color;
+        glColorNode          *color_node;
+        guint                 format_digits;
+        gdouble               w, h;
 
 	gl_debug (DEBUG_LABEL, "START");
 
@@ -437,36 +494,50 @@ draw_object (glLabelObject *object,
 
 	} else {
 
-		for (li = gbc->lines; li != NULL; li = li->next) {
-			line = (glBarcodeLine *) li->data;
+		for (p = gbc->shapes; p != NULL; p = p->next) {
+                        shape = (glBarcodeShape *)p->data;
+                        switch (shape->type)
+                        {
 
-			cairo_move_to (cr, line->x, line->y);
-			cairo_line_to (cr, line->x, line->y + line->length);
-			cairo_set_line_width (cr, line->width);
-			cairo_stroke (cr);
-		}
+                        case GL_BARCODE_SHAPE_LINE:
+                                line = (glBarcodeShapeLine *) shape;
 
-		for (li = gbc->chars; li != NULL; li = li->next) {
-			bchar = (glBarcodeChar *) li->data;
+                                cairo_move_to (cr, line->x, line->y);
+                                cairo_line_to (cr, line->x, line->y + line->length);
+                                cairo_set_line_width (cr, line->width);
+                                cairo_stroke (cr);
 
-                        layout = pango_cairo_create_layout (cr);
+                                break;
 
-                        desc = pango_font_description_new ();
-                        pango_font_description_set_family (desc, GL_BARCODE_FONT_FAMILY);
-                        pango_font_description_set_size   (desc, bchar->fsize * PANGO_SCALE * FONT_SCALE);
-                        pango_layout_set_font_description (layout, desc);
-                        pango_font_description_free       (desc);
+                        case GL_BARCODE_SHAPE_ALPHA:
+                                bchar = (glBarcodeShapeAlpha *) shape;
 
-			cstring = g_strdup_printf ("%c", bchar->c);
-                        pango_layout_set_text (layout, cstring, -1);
-			g_free (cstring);
+                                layout = pango_cairo_create_layout (cr);
 
-                        y_offset = 0.2 * bchar->fsize;
+                                desc = pango_font_description_new ();
+                                pango_font_description_set_family (desc, GL_BARCODE_FONT_FAMILY);
+                                pango_font_description_set_size   (desc, bchar->fsize * PANGO_SCALE * FONT_SCALE);
+                                pango_layout_set_font_description (layout, desc);
+                                pango_font_description_free       (desc);
 
-			cairo_move_to (cr, bchar->x, bchar->y-y_offset);
-                        pango_cairo_show_layout (cr, layout);
+                                cstring = g_strdup_printf ("%c", bchar->c);
+                                pango_layout_set_text (layout, cstring, -1);
+                                g_free (cstring);
 
-                        g_object_unref (layout);
+                                y_offset = 0.2 * bchar->fsize;
+
+                                cairo_move_to (cr, bchar->x, bchar->y-y_offset);
+                                pango_cairo_show_layout (cr, layout);
+
+                                g_object_unref (layout);
+
+                                break;
+
+                        default:
+                                g_assert_not_reached ();
+                                break;
+
+                        }
 
 		}
 
@@ -481,3 +552,39 @@ draw_object (glLabelObject *object,
 	gl_debug (DEBUG_LABEL, "END");
 }
 
+
+/*****************************************************************************/
+/* Is object at coordinates?                                                 */
+/*****************************************************************************/
+static gboolean
+object_at (glLabelObject *object,
+           cairo_t       *cr,
+           gdouble        x,
+           gdouble        y)
+{
+        gdouble           w, h;
+
+        gl_label_object_get_size (object, &w, &h);
+
+        cairo_new_path (cr);
+        cairo_rectangle (cr, 0.0, 0.0, w, h);
+
+        if (cairo_in_fill (cr, x, y))
+        {
+                return TRUE;
+        }
+
+        return FALSE;
+}
+
+
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
