@@ -1,34 +1,30 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  label-image.h
+ *  Copyright (C) 2001-2009  Jim Evins <evins@snaught.com>.
  *
- *  label_image.h:  GLabels label image object
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2001-2002  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LABEL_IMAGE_H__
 #define __LABEL_IMAGE_H__
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include "label-object.h"
 #include "text-node.h"
 #include "merge.h"
-#include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
 
@@ -56,10 +52,16 @@ struct _glLabelImageClass {
 
 GType            gl_label_image_get_type     (void) G_GNUC_CONST;
 
-GObject         *gl_label_image_new          (glLabel       *label);
+GObject         *gl_label_image_new          (glLabel       *label,
+                                              gboolean       checkpoint);
 
 void             gl_label_image_set_filename (glLabelImage  *limage,
-					      glTextNode    *filename);
+					      glTextNode    *filename,
+                                              gboolean       checkpoint);
+
+void             gl_label_image_set_pixbuf   (glLabelImage  *limage,
+					      GdkPixbuf     *pixbuf,
+                                              gboolean       checkpoint);
 
 glTextNode      *gl_label_image_get_filename (glLabelImage  *limage);
 
@@ -69,3 +71,15 @@ const GdkPixbuf *gl_label_image_get_pixbuf   (glLabelImage  *limage,
 G_END_DECLS
 
 #endif /* __LABEL_IMAGE_H__ */
+
+
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
