@@ -1,25 +1,21 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  merge-text.c
+ *  Copyright (C) 2001-2009  Jim Evins <evins@snaught.com>.
  *
- *  merge_text.c:  text-file merge backend module
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2001  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -32,13 +28,20 @@
 
 #define LINE_BUF_LEN 1024
 
+
 /*===========================================*/
 /* Private types                             */
 /*===========================================*/
 
 struct _glMergeTextPrivate {
+
 	gchar             delim;
+        gboolean          line1_has_keys;
+
 	FILE             *fp;
+
+        GPtrArray        *keys;
+        gint              n_fields_max;
 };
 
 enum {
@@ -48,8 +51,10 @@ enum {
 enum {
 	ARG_0,
 	ARG_DELIM,
+	ARG_LINE1_HAS_KEYS,
 };
 
+
 /*===========================================*/
 /* Private globals                           */
 /*===========================================*/
@@ -71,6 +76,10 @@ static void           gl_merge_text_get_property    (GObject          *object,
 						     GValue           *value,
 						     GParamSpec       *pspec);
 
+static gchar         *key_from_index                (glMergeText      *merge_text,
+                                                     gint              i_field);
+static void           clear_keys                    (glMergeText      *merge_text);
+
 static GList         *gl_merge_text_get_key_list    (glMerge          *merge);
 static gchar         *gl_merge_text_get_primary_key (glMerge          *merge);
 static void           gl_merge_text_open            (glMerge          *merge);
@@ -84,12 +93,14 @@ static GList         *parse_line                    (FILE             *fp,
 static gchar         *parse_field                   (gchar            *raw_field);
 static void           free_fields                   (GList           **fields);
 
-
+
+
 /*****************************************************************************/
 /* Boilerplate object stuff.                                                 */
 /*****************************************************************************/
 G_DEFINE_TYPE (glMergeText, gl_merge_text, GL_TYPE_MERGE);
 
+
 static void
 gl_merge_text_class_init (glMergeTextClass *class)
 {
@@ -110,6 +121,13 @@ gl_merge_text_class_init (glMergeTextClass *class)
 				    0, 0x7F, ',',
 				    (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 
+	g_object_class_install_property
+                (object_class,
+                 ARG_LINE1_HAS_KEYS,
+                 g_param_spec_boolean ("line1_has_keys", NULL, NULL,
+                                       FALSE,
+                                       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+
 	object_class->finalize = gl_merge_text_finalize;
 
 	merge_class->get_key_list    = gl_merge_text_get_key_list;
@@ -122,6 +140,7 @@ gl_merge_text_class_init (glMergeTextClass *class)
 	gl_debug (DEBUG_MERGE, "END");
 }
 
+
 static void
 gl_merge_text_init (glMergeText *merge_text)
 {
@@ -129,9 +148,12 @@ gl_merge_text_init (glMergeText *merge_text)
 
 	merge_text->priv = g_new0 (glMergeTextPrivate, 1);
 
+        merge_text->priv->keys = g_ptr_array_new ();
+
 	gl_debug (DEBUG_MERGE, "END");
 }
 
+
 static void
 gl_merge_text_finalize (GObject *object)
 {
@@ -141,6 +163,8 @@ gl_merge_text_finalize (GObject *object)
 
 	g_return_if_fail (object && GL_IS_MERGE_TEXT (object));
 
+        clear_keys (merge_text);
+        g_ptr_array_free (merge_text->priv->keys, TRUE);
 	g_free (merge_text->priv);
 
 	G_OBJECT_CLASS (gl_merge_text_parent_class)->finalize (object);
@@ -148,6 +172,7 @@ gl_merge_text_finalize (GObject *object)
 	gl_debug (DEBUG_MERGE, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Set argument.                                                            */
 /*--------------------------------------------------------------------------*/
@@ -169,6 +194,12 @@ gl_merge_text_set_property (GObject      *object,
 			  merge_text->priv->delim);
 		break;
 
+        case ARG_LINE1_HAS_KEYS:
+                merge_text->priv->line1_has_keys = g_value_get_boolean (value);
+		gl_debug (DEBUG_MERGE, "ARG \"line1_has_keys\" = \"%d\"",
+			  merge_text->priv->line1_has_keys);
+		break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
                 break;
@@ -177,6 +208,7 @@ gl_merge_text_set_property (GObject      *object,
 
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Get argument.                                                            */
 /*--------------------------------------------------------------------------*/
@@ -196,6 +228,10 @@ gl_merge_text_get_property (GObject     *object,
 		g_value_set_char (value, merge_text->priv->delim);
 		break;
 
+        case ARG_LINE1_HAS_KEYS:
+                g_value_set_boolean (value, merge_text->priv->line1_has_keys);
+                break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
                 break;
@@ -204,6 +240,42 @@ gl_merge_text_get_property (GObject     *object,
 
 }
 
+
+/*---------------------------------------------------------------------------*/
+/* Lookup key name from zero based index.                                    */
+/*---------------------------------------------------------------------------*/
+static gchar *
+key_from_index (glMergeText  *merge_text,
+                gint          i_field)
+{
+        if ( merge_text->priv->line1_has_keys &&
+             (i_field < merge_text->priv->keys->len) )
+        {
+                return g_strdup (g_ptr_array_index (merge_text->priv->keys, i_field));
+        }
+        else
+        {
+                return g_strdup_printf ("%d", i_field+1);
+        }
+}
+
+
+/*---------------------------------------------------------------------------*/
+/* Clear stored keys.                                                        */
+/*---------------------------------------------------------------------------*/
+static void
+clear_keys (glMergeText      *merge_text)
+{
+        gint i;
+
+        for ( i = 0; i < merge_text->priv->keys->len; i++ )
+        {
+                g_free (g_ptr_array_index (merge_text->priv->keys, i));
+        }
+        merge_text->priv->keys->len = 0;
+}
+
+
 /*--------------------------------------------------------------------------*/
 /* Get key list.                                                            */
 /*--------------------------------------------------------------------------*/
@@ -211,41 +283,34 @@ static GList *
 gl_merge_text_get_key_list (glMerge *merge)
 {
 	glMergeText   *merge_text;
-	GList         *record_list, *p_rec;
-	glMergeRecord *record;
-	GList         *p_field;
-	gint           i_field, n_fields, n_fields_max = 0;
+	gint           i_field, n_fields;
 	GList         *key_list;
 	
-	/* Field keys are simply column numbers. */
-
 	gl_debug (DEBUG_MERGE, "BEGIN");
 
 	merge_text = GL_MERGE_TEXT (merge);
 
-	record_list = (GList *)gl_merge_get_record_list (merge);
-
-	for ( p_rec=record_list; p_rec!=NULL; p_rec=p_rec->next ) {
-		record = (glMergeRecord *)p_rec->data;
-
-		n_fields = 0;
-		for ( p_field=record->field_list; p_field!=NULL; p_field=p_field->next ) {
-			n_fields++;
-		}
-		if ( n_fields > n_fields_max ) n_fields_max = n_fields;
-	}
-
-	key_list = NULL;
-	for (i_field=1; i_field <= n_fields_max; i_field++) {
-		key_list = g_list_append (key_list, g_strdup_printf ("%d", i_field));
-	}
+        if ( merge_text->priv->line1_has_keys )
+        {
+                n_fields = merge_text->priv->keys->len;
+        }
+        else
+        {
+                n_fields = merge_text->priv->n_fields_max;
+        }
 
+        key_list = NULL;
+        for ( i_field=0; i_field < n_fields; i_field++ )
+        {
+                key_list = g_list_append (key_list, key_from_index(merge_text, i_field));
+        }
 
 	gl_debug (DEBUG_MERGE, "END");
 
 	return key_list;
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Get "primary" key.                                                       */
 /*--------------------------------------------------------------------------*/
@@ -253,9 +318,10 @@ static gchar *
 gl_merge_text_get_primary_key (glMerge *merge)
 {
 	/* For now, let's always assume the first column is the primary key. */
-	return g_strdup ("1");
+        return key_from_index (GL_MERGE_TEXT (merge), 0);
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Open merge source.                                                       */
 /*--------------------------------------------------------------------------*/
@@ -265,17 +331,45 @@ gl_merge_text_open (glMerge *merge)
 	glMergeText *merge_text;
 	gchar       *src;
 
+        GList       *line1_fields;
+        GList       *p;
+
 	merge_text = GL_MERGE_TEXT (merge);
 
 	src = gl_merge_get_src (merge);
 
-	if (src != NULL) {
-		merge_text->priv->fp = fopen (src, "r");
+	if (src != NULL)
+        {
+		if (g_utf8_strlen(src, -1) == 1 && src[0] == '-')
+			merge_text->priv->fp = stdin;
+		else
+			merge_text->priv->fp = fopen (src, "r");
+
+                g_free (src);
+
+                clear_keys (merge_text);
+                merge_text->priv->n_fields_max = 0;
+
+                if ( merge_text->priv->line1_has_keys )
+                {
+                        /*
+                         * Extract keys from first line and discard line
+                         */
+
+                        line1_fields = parse_line (merge_text->priv->fp, merge_text->priv->delim);
+                        for ( p = line1_fields; p != NULL; p = p->next )
+                        {
+                                g_ptr_array_add (merge_text->priv->keys, g_strdup (p->data));
+                        }
+                        free_fields (&line1_fields);
+                }
+
 	}
 
-	g_free (src);
+
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Close merge source.                                                      */
 /*--------------------------------------------------------------------------*/
@@ -294,6 +388,7 @@ gl_merge_text_close (glMerge *merge)
 	}
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* Get next record from merge source, NULL if no records left (i.e EOF)     */
 /*--------------------------------------------------------------------------*/
@@ -313,10 +408,6 @@ gl_merge_text_get_record (glMerge *merge)
 	delim = merge_text->priv->delim;
 	fp    = merge_text->priv->fp;
 
-	if (fp == NULL) {
-		return NULL;
-	}
-	       
 	fields = parse_line (fp, delim);
 	if ( fields == NULL ) {
 		return NULL;
@@ -324,11 +415,10 @@ gl_merge_text_get_record (glMerge *merge)
 
 	record = g_new0 (glMergeRecord, 1);
 	record->select_flag = TRUE;
-	i_field = 1;
-	for (p=fields; p != NULL; p=p->next) {
+	for (p=fields, i_field=0; p != NULL; p=p->next, i_field++) {
 
 		field = g_new0 (glMergeField, 1);
-		field->key = g_strdup_printf ("%d", i_field++);
+                field->key = key_from_index (merge_text, i_field);
 #ifndef CSV_ALWAYS_UTF8
 		field->value = g_locale_to_utf8 (p->data, -1, NULL, NULL, NULL);
 #else
@@ -339,9 +429,15 @@ gl_merge_text_get_record (glMerge *merge)
 	}
 	free_fields (&fields);
 
+        if ( i_field > merge_text->priv->n_fields_max )
+        {
+                merge_text->priv->n_fields_max = i_field;
+        }
+
 	return record;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* Copy merge_text specific fields.                                          */
 /*---------------------------------------------------------------------------*/
@@ -351,13 +447,24 @@ gl_merge_text_copy (glMerge *dst_merge,
 {
 	glMergeText *dst_merge_text;
 	glMergeText *src_merge_text;
+        gint         i;
 
 	dst_merge_text = GL_MERGE_TEXT (dst_merge);
 	src_merge_text = GL_MERGE_TEXT (src_merge);
 
-	dst_merge_text->priv->delim = src_merge_text->priv->delim;
+	dst_merge_text->priv->delim          = src_merge_text->priv->delim;
+	dst_merge_text->priv->line1_has_keys = src_merge_text->priv->line1_has_keys;
+
+        for ( i=0; i < src_merge_text->priv->keys->len; i++ )
+        {
+                g_ptr_array_add (dst_merge_text->priv->keys,
+                                 g_strdup ((gchar *)g_ptr_array_index (src_merge_text->priv->keys, i)));
+        }
+
+	dst_merge_text->priv->n_fields_max   = src_merge_text->priv->n_fields_max;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* PRIVATE.  Parse line.                                                     */
 /*                                                                           */
@@ -388,6 +495,10 @@ parse_line (FILE  *fp,
 	enum { BEGIN, NORMAL, QUOTED, QUOTED_QUOTE1,
                NORMAL_ESCAPED, QUOTED_ESCAPED, DONE } state;
 
+	if (fp == NULL) {
+		return NULL;
+	}
+	       
 	state = BEGIN;
 	string = g_string_new( "" );
 	while ( state != DONE ) {
@@ -544,6 +655,7 @@ parse_line (FILE  *fp,
 	return list;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* PRIVATE.  Parse field.                                                    */
 /*                                                                           */
@@ -675,6 +787,7 @@ parse_field (gchar  *raw_field)
 	return field;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /* Free list of fields.                                                      */
 /*---------------------------------------------------------------------------*/
@@ -692,3 +805,13 @@ free_fields (GList ** list)
 	*list = NULL;
 }
 
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
