@@ -1,24 +1,23 @@
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  merge.h
+ *  Copyright (C) 2002-2009  Jim Evins <evins@snaught.com>.
  *
- *  merge.h:  document merge module header file
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2002  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #ifndef __MERGE_H__
 #define __MERGE_H__
 
@@ -59,7 +58,7 @@ typedef struct _glMergePrivate   glMergePrivate;
 struct _glMerge {
 	GObject          object;
 
-	glMergePrivate  *private;
+	glMergePrivate  *priv;
 };
 
 struct _glMergeClass {
@@ -126,3 +125,14 @@ gint              gl_merge_get_record_count    (glMerge           *merge);
 G_END_DECLS
 
 #endif
+
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
