@@ -1,58 +1,58 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  object-editor-shadow-page.c
+ *  Copyright (C) 2006-2009  Jim Evins <evins@snaught.com>.
  *
- *  object-editor.c:  object properties editor module
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2006  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #include <config.h>
 
 #include "object-editor.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkcombobox.h>
+#include <gtk/gtk.h>
 #include <math.h>
 
 #include "prefs.h"
-#include "mygal/widget-color-combo.h"
+#include "color-combo.h"
 #include "color.h"
-#include "util.h"
+#include "field-button.h"
+#include "builder-util.h"
+#include "units-util.h"
 
 #include "object-editor-private.h"
 
 #include "debug.h"
 
+
 /*===========================================*/
 /* Private macros                            */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Private data types                        */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Private globals                           */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Local function prototypes                 */
 /*===========================================*/
@@ -67,6 +67,7 @@ static void shadow_color_radio_toggled_cb  (glObjectEditor        *editor);
 void
 gl_object_editor_prepare_shadow_page (glObjectEditor *editor)
 {
+        lglUnits      units;
 	const gchar  *units_string;
 	gdouble       climb_rate;
 	gint          digits;
@@ -74,38 +75,39 @@ gl_object_editor_prepare_shadow_page (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "START");
 
 	/* Extract widgets from XML tree. */
-	editor->priv->shadow_page_vbox
-		= glade_xml_get_widget (editor->priv->gui, "shadow_page_vbox");
-	editor->priv->shadow_enable_check
-		= glade_xml_get_widget (editor->priv->gui, "shadow_enable_check");
-	editor->priv->shadow_controls_table
-		= glade_xml_get_widget (editor->priv->gui, "shadow_controls_table");
-	editor->priv->shadow_x_spin
-		= glade_xml_get_widget (editor->priv->gui, "shadow_x_spin");
-	editor->priv->shadow_y_spin
-		= glade_xml_get_widget (editor->priv->gui, "shadow_y_spin");
-	editor->priv->shadow_x_units_label
-		= glade_xml_get_widget (editor->priv->gui, "shadow_x_units_label");
-	editor->priv->shadow_y_units_label
-		= glade_xml_get_widget (editor->priv->gui, "shadow_y_units_label");
-	editor->priv->shadow_color_radio
-		= glade_xml_get_widget (editor->priv->gui, "shadow_color_radio");	
-	editor->priv->shadow_key_radio
-		= glade_xml_get_widget (editor->priv->gui, "shadow_key_radio");	
-	editor->priv->shadow_color_combo
-		= glade_xml_get_widget (editor->priv->gui, "shadow_color_combo");
-	editor->priv->shadow_key_combo
-		= glade_xml_get_widget (editor->priv->gui, "shadow_key_combo");	
-	editor->priv->shadow_opacity_spin
-		= glade_xml_get_widget (editor->priv->gui, "shadow_opacity_spin");
+        gl_builder_util_get_widgets (editor->priv->builder,
+                                     "shadow_page_vbox",      &editor->priv->shadow_page_vbox,
+                                     "shadow_enable_check",   &editor->priv->shadow_enable_check,
+                                     "shadow_controls_table", &editor->priv->shadow_controls_table,
+                                     "shadow_x_spin",         &editor->priv->shadow_x_spin,
+                                     "shadow_y_spin",         &editor->priv->shadow_y_spin,
+                                     "shadow_x_units_label",  &editor->priv->shadow_x_units_label,
+                                     "shadow_y_units_label",  &editor->priv->shadow_y_units_label,
+                                     "shadow_color_radio",    &editor->priv->shadow_color_radio,
+                                     "shadow_key_radio",      &editor->priv->shadow_key_radio,
+                                     "shadow_color_hbox",     &editor->priv->shadow_color_hbox,
+                                     "shadow_key_hbox",       &editor->priv->shadow_key_hbox,
+                                     "shadow_opacity_spin",   &editor->priv->shadow_opacity_spin,
+                                     NULL);
+
+	editor->priv->shadow_color_combo = gl_color_combo_new (_("Default"),
+                                                               GL_COLOR_SHADOW_DEFAULT,
+                                                               GL_COLOR_SHADOW_DEFAULT);
+        gtk_container_add (GTK_CONTAINER (editor->priv->shadow_color_hbox),
+                           editor->priv->shadow_color_combo);
+
+        editor->priv->shadow_key_combo = gl_field_button_new (NULL);
+        gtk_box_pack_start (GTK_BOX (editor->priv->shadow_key_hbox),
+                            editor->priv->shadow_key_combo,
+                            TRUE, TRUE, 0);
 
-	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->shadow_key_combo));
 
 	/* Get configuration information */
-	units_string = gl_prefs_get_units_string ();
-	editor->priv->units_per_point = gl_prefs_get_units_per_point ();
-	climb_rate = gl_prefs_get_units_step_size ();
-	digits = gl_prefs_get_units_precision ();
+        units = gl_prefs_model_get_units (gl_prefs);
+	units_string = lgl_units_get_name (units);
+	editor->priv->units_per_point = lgl_units_get_units_per_point (units);
+	climb_rate = gl_units_util_get_step_size (units);
+	digits = gl_units_util_get_precision (units);
 
 	/* Modify widgets based on configuration */
 	gtk_spin_button_set_digits (GTK_SPIN_BUTTON(editor->priv->shadow_x_spin), digits);
@@ -157,6 +159,7 @@ gl_object_editor_prepare_shadow_page (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* Set shadow parameters.                                                    */
 /*****************************************************************************/
@@ -177,6 +180,7 @@ gl_object_editor_set_shadow_state (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 void
 gl_object_editor_set_shadow_offset (glObjectEditor      *editor,
 				    gdouble              x,
@@ -205,33 +209,35 @@ gl_object_editor_set_shadow_offset (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 void
 gl_object_editor_set_shadow_color (glObjectEditor      *editor,
 				   gboolean             merge_flag,
 				   glColorNode         *color_node)
 {
-	GdkColor *gdk_color;
-
 	gl_debug (DEBUG_EDITOR, "START");
 
+        if (color_node == NULL)
+        {
+                return;
+        }
+
         editor->priv->stop_signals = TRUE;
 
 	gtk_widget_set_sensitive (editor->priv->shadow_key_radio, merge_flag);
 
 	if ( color_node->color == GL_COLOR_NONE ) {
 
-		color_combo_set_color_to_default (COLOR_COMBO(editor->priv->shadow_color_combo));
+		gl_color_combo_set_to_default (GL_COLOR_COMBO(editor->priv->shadow_color_combo));
 
 	} else {
 
-		gdk_color = gl_color_to_gdk_color (color_node->color);
-		color_combo_set_color (COLOR_COMBO(editor->priv->shadow_color_combo),
-					   gdk_color);
-		g_free (gdk_color);
+		gl_color_combo_set_color (GL_COLOR_COMBO(editor->priv->shadow_color_combo),
+                                          color_node->color);
 
 	}
 	
-	if (!color_node->field_flag) {
+	if (!color_node->field_flag || !merge_flag) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 						  (editor->priv->shadow_color_radio), TRUE); 
 		gtk_widget_set_sensitive (editor->priv->shadow_color_combo, TRUE);
@@ -243,8 +249,8 @@ gl_object_editor_set_shadow_color (glObjectEditor      *editor,
 		gtk_widget_set_sensitive (editor->priv->shadow_color_combo, FALSE);
 		gtk_widget_set_sensitive (editor->priv->shadow_key_combo, TRUE);
 		
-		gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->shadow_key_combo),
-						   color_node->key);
+		gl_field_button_set_key (GL_FIELD_BUTTON (editor->priv->shadow_key_combo),
+                                         color_node->key);
 	}
 	
         editor->priv->stop_signals = FALSE;
@@ -252,6 +258,7 @@ gl_object_editor_set_shadow_color (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 void
 gl_object_editor_set_shadow_opacity (glObjectEditor      *editor,
 				     gdouble              alpha)
@@ -313,6 +320,7 @@ gl_object_editor_set_max_shadow_offset (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* Query shadow parameters.                                                  */
 /*****************************************************************************/
@@ -330,6 +338,7 @@ gl_object_editor_get_shadow_state (glObjectEditor      *editor)
 	return state;
 }
 
+
 void
 gl_object_editor_get_shadow_offset (glObjectEditor      *editor,
 				    gdouble             *x,
@@ -352,10 +361,11 @@ gl_object_editor_get_shadow_offset (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 glColorNode*
 gl_object_editor_get_shadow_color (glObjectEditor      *editor)
 {
-        GdkColor    *gdk_color;
+        guint        color;
         gboolean     is_default;
 	glColorNode *color_node;
  
@@ -366,16 +376,16 @@ gl_object_editor_get_shadow_color (glObjectEditor      *editor)
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->shadow_key_radio))) {
 		color_node->field_flag = TRUE;
 		color_node->key = 
-			gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->shadow_key_combo));
-    } else {
+			gl_field_button_get_key (GL_FIELD_BUTTON (editor->priv->shadow_key_combo));
+        } else {
 		color_node->field_flag = FALSE;
 		color_node->key = NULL;
-		gdk_color = color_combo_get_color (COLOR_COMBO(editor->priv->shadow_color_combo),
-                                           &is_default);
+		color = gl_color_combo_get_color (GL_COLOR_COMBO(editor->priv->shadow_color_combo),
+                                                  &is_default);
 
 		if (!is_default) {
-        	color_node->color = gl_color_from_gdk_color (gdk_color);
-        }
+                        color_node->color = color;
+                }
 	}
 
 	gl_debug (DEBUG_EDITOR, "END");
@@ -383,6 +393,7 @@ gl_object_editor_get_shadow_color (glObjectEditor      *editor)
 	return color_node;
 }
 
+
 gdouble
 gl_object_editor_get_shadow_opacity (glObjectEditor      *editor)
 {
@@ -404,6 +415,7 @@ gl_object_editor_get_shadow_opacity (glObjectEditor      *editor)
 void
 shadow_prefs_changed_cb (glObjectEditor *editor)
 {
+        lglUnits      units;
 	const gchar  *units_string;
 	gdouble       climb_rate;
 	gint          digits;
@@ -411,10 +423,11 @@ shadow_prefs_changed_cb (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "START");
 
         /* Get new configuration information */
-        units_string = gl_prefs_get_units_string ();
-        editor->priv->units_per_point = gl_prefs_get_units_per_point ();
-        climb_rate = gl_prefs_get_units_step_size ();
-        digits = gl_prefs_get_units_precision ();
+        units = gl_prefs_model_get_units (gl_prefs);
+        units_string = lgl_units_get_name (units);
+        editor->priv->units_per_point = lgl_units_get_units_per_point (units);
+        climb_rate = gl_units_util_get_step_size (units);
+        digits = gl_units_util_get_precision (units);
 
 	/* Update characteristics of x_spin/y_spin */
         editor->priv->stop_signals = TRUE;
@@ -445,6 +458,7 @@ shadow_prefs_changed_cb (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* PRIVATE.  shadow enable check callback.                                  */
 /*--------------------------------------------------------------------------*/
@@ -461,8 +475,7 @@ shadow_enable_check_toggled_cb (glObjectEditor *editor)
 
         gtk_widget_set_sensitive (editor->priv->shadow_controls_table, state);
 
-        /* Emit our "changed" signal */
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
+        gl_object_editor_changed_cb (editor);
 
         gl_debug (DEBUG_EDITOR, "END");
 }
@@ -487,8 +500,18 @@ shadow_color_radio_toggled_cb (glObjectEditor *editor)
 		
 	}
  
-        /* Emit our "changed" signal */
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
+        gl_object_editor_changed_cb (editor);
  
         gl_debug (DEBUG_EDITOR, "END");
 }
+
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
