@@ -1,54 +1,56 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  object-editor-size-page.c
+ *  Copyright (C) 2003-2009  Jim Evins <evins@snaught.com>.
  *
- *  object-editor.c:  object properties editor module
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2003  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #include <config.h>
 
 #include "object-editor.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkspinbutton.h>
+#include <gtk/gtk.h>
 #include <math.h>
 
 #include "prefs.h"
 #include "wdgt-chain-button.h"
+#include "builder-util.h"
+#include "units-util.h"
 
 #include "object-editor-private.h"
 
 #include "debug.h"
 
+
 /*===========================================*/
 /* Private macros                            */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Private data types                        */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Private globals                           */
 /*===========================================*/
 
+
 /*===========================================*/
 /* Local function prototypes                 */
 /*===========================================*/
@@ -63,9 +65,9 @@ static void h_spin_cb                           (glObjectEditor        *editor);
 /* PRIVATE.  Prepare size page.                                             */
 /*--------------------------------------------------------------------------*/
 void
-gl_object_editor_prepare_size_page (glObjectEditor       *editor,
-				    glObjectEditorOption  option)
+gl_object_editor_prepare_size_page (glObjectEditor       *editor)
 {
+        lglUnits      units;
 	const gchar  *units_string;
 	gdouble       climb_rate;
 	gint          digits;
@@ -73,26 +75,30 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 	gl_debug (DEBUG_EDITOR, "START");
 
 	/* Extract widgets from XML tree. */
-	editor->priv->size_page_vbox =
-		glade_xml_get_widget (editor->priv->gui, "size_page_vbox");
-	editor->priv->size_w_spin =
-		glade_xml_get_widget (editor->priv->gui, "size_w_spin");
-	editor->priv->size_h_spin =
-		glade_xml_get_widget (editor->priv->gui, "size_h_spin");
-	editor->priv->size_w_units_label =
-		glade_xml_get_widget (editor->priv->gui, "size_w_units_label");
-	editor->priv->size_h_units_label =
-		glade_xml_get_widget (editor->priv->gui, "size_h_units_label");
-	editor->priv->size_aspect_checkbutton =
-		glade_xml_get_widget (editor->priv->gui, "size_aspect_checkbutton");
-	editor->priv->size_reset_image_button =
-		glade_xml_get_widget (editor->priv->gui, "size_reset_image_button");
+        gl_builder_util_get_widgets (editor->priv->builder,
+                                     "size_page_vbox",          &editor->priv->size_page_vbox,
+                                     "size_w_spin",             &editor->priv->size_w_spin,
+                                     "size_h_spin",             &editor->priv->size_h_spin,
+                                     "size_w_units_label",      &editor->priv->size_w_units_label,
+                                     "size_h_units_label",      &editor->priv->size_h_units_label,
+                                     "size_aspect_vbox",        &editor->priv->size_aspect_vbox,
+                                     "size_reset_image_button", &editor->priv->size_reset_image_button,
+                                     NULL);
+
+	editor->priv->size_aspect_checkbutton = gl_wdgt_chain_button_new (GL_WDGT_CHAIN_RIGHT);
+	gl_wdgt_chain_button_set_active (GL_WDGT_CHAIN_BUTTON(editor->priv->size_aspect_checkbutton),
+                                         TRUE);
+        gtk_box_pack_start (GTK_BOX (editor->priv->size_aspect_vbox),
+                            editor->priv->size_aspect_checkbutton,
+                            FALSE, FALSE, 0);
+
 
 	/* Get configuration information */
-	units_string = gl_prefs_get_units_string ();
-	editor->priv->units_per_point = gl_prefs_get_units_per_point ();
-	climb_rate = gl_prefs_get_units_step_size ();
-	digits = gl_prefs_get_units_precision ();
+        units = gl_prefs_model_get_units (gl_prefs);
+	units_string = lgl_units_get_name (units);
+	editor->priv->units_per_point = lgl_units_get_units_per_point (units);
+	climb_rate = gl_units_util_get_step_size (units);
+	digits = gl_units_util_get_precision (units);
 
 	/* Modify widgets based on configuration */
 	gtk_spin_button_set_digits (GTK_SPIN_BUTTON(editor->priv->size_w_spin), digits);
@@ -104,11 +110,6 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 					climb_rate, 10.0*climb_rate);
 	gtk_label_set_text (GTK_LABEL(editor->priv->size_h_units_label), units_string);
 
-	/* Un-hide */
-	gtk_widget_show_all (editor->priv->size_page_vbox);
-	if (option != GL_OBJECT_EDITOR_SIZE_IMAGE_PAGE) {
-		gtk_widget_hide (editor->priv->size_reset_image_button);
-	}
 
 	/* Connect signals */
 	g_signal_connect_swapped (G_OBJECT (editor->priv->size_aspect_checkbutton),
@@ -123,17 +124,15 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 				  "changed",
 				  G_CALLBACK (h_spin_cb),
 				  G_OBJECT (editor));
-
-	if (option == GL_OBJECT_EDITOR_SIZE_IMAGE_PAGE) {
-		g_signal_connect_swapped (G_OBJECT (editor->priv->size_reset_image_button),
-					  "clicked",
-					  G_CALLBACK (size_reset_cb),
-					  G_OBJECT (editor));
-	}
+        g_signal_connect_swapped (G_OBJECT (editor->priv->size_reset_image_button),
+                                  "clicked",
+                                  G_CALLBACK (size_reset_cb),
+                                  G_OBJECT (editor));
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* PRIVATE.  Maintain aspect ratio checkbox callback.                       */
 /*--------------------------------------------------------------------------*/
@@ -161,6 +160,7 @@ aspect_toggle_cb (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* PRIVATE.  W spin button changed callback.                                */
 /*--------------------------------------------------------------------------*/
@@ -188,13 +188,12 @@ w_spin_cb (glObjectEditor *editor)
                 editor->priv->stop_signals = FALSE;
         }
                                                                                 
-        /* Emit our "changed" signal */
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[SIZE_CHANGED], 0);
+        gl_object_editor_size_changed_cb (editor);
                                                                                 
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* PRIVATE.  H spin button changed callback.                                */
 /*--------------------------------------------------------------------------*/
@@ -222,13 +221,12 @@ h_spin_cb (glObjectEditor *editor)
                 editor->priv->stop_signals = FALSE;
         }
                                                                                 
-        /* Emit our "changed" signal */
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[SIZE_CHANGED], 0);
+        gl_object_editor_size_changed_cb (editor);
                                                                                 
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*--------------------------------------------------------------------------*/
 /* PRIVATE.  Reset image size callback.                                     */
 /*--------------------------------------------------------------------------*/
@@ -274,15 +272,14 @@ size_reset_cb (glObjectEditor *editor)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->priv->size_h_spin),
 				   h_base);
 
-        /* Emit our "changed" signal */
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
-        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[SIZE_CHANGED], 0);
-
         editor->priv->stop_signals = FALSE;
 
+        gl_object_editor_size_changed_cb (editor);
+
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* Set size.                                                                 */
 /*****************************************************************************/
@@ -317,6 +314,7 @@ gl_object_editor_set_size (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* Set maximum size.                                                         */
 /*****************************************************************************/
@@ -363,6 +361,7 @@ gl_object_editor_set_max_size (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* Set base or natural size of image.                                        */
 /*****************************************************************************/
@@ -378,6 +377,7 @@ gl_object_editor_set_base_size    (glObjectEditor      *editor,
 	editor->priv->h_base = h_base;
 }
 
+
 /*****************************************************************************/
 /* Query size.                                                               */
 /*****************************************************************************/
@@ -404,12 +404,14 @@ gl_object_editor_get_size (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
 /*****************************************************************************/
 /* PRIVATE. Prefs changed callback.  Update units related items.            */
 /*****************************************************************************/
 void
 size_prefs_changed_cb (glObjectEditor *editor)
 {
+        lglUnits      units;
 	const gchar  *units_string;
 	gdouble       climb_rate;
 	gint          digits;
@@ -417,10 +419,11 @@ size_prefs_changed_cb (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "START");
 
         /* Get new configuration information */
-        units_string = gl_prefs_get_units_string ();
-        editor->priv->units_per_point = gl_prefs_get_units_per_point ();
-        climb_rate = gl_prefs_get_units_step_size ();
-        digits = gl_prefs_get_units_precision ();
+        units = gl_prefs_model_get_units (gl_prefs);
+        units_string = lgl_units_get_name (units);
+        editor->priv->units_per_point = lgl_units_get_units_per_point (units);
+        climb_rate = gl_units_util_get_step_size (units);
+        digits = gl_units_util_get_precision (units);
 
 	/* Update characteristics of w_spin/h_spin */
         editor->priv->stop_signals = TRUE;
@@ -451,3 +454,13 @@ size_prefs_changed_cb (glObjectEditor *editor)
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
