@@ -1,37 +1,30 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-
 /*
- *  (GLABELS) Label and Business Card Creation program for GNOME
+ *  ui.c
+ *  Copyright (C) 2001-2009  Jim Evins <evins@snaught.com>.
  *
- *  ui.c:  GLabels ui module
+ *  This file is part of gLabels.
  *
- *  Copyright (C) 2001-2002  Jim Evins <evins@snaught.com>.
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  gLabels is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  gLabels is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *  along with gLabels.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #include <config.h>
 
 #include "ui.h"
 
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <gtk/gtkrecentchoosermenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtkstatusbar.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 #include "ui-util.h"
@@ -44,10 +37,12 @@
 
 #include "debug.h"
 
+
 /*==========================================================================*/
 /* Private macros and constants.                                            */
 /*==========================================================================*/
 
+
 /*==========================================================================*/
 /* Private types.                                                           */
 /*==========================================================================*/
@@ -66,6 +61,11 @@ static void set_app_drawing_toolbar_style  (GtkUIManager    *ui);
 
 static void set_view_style                 (GtkUIManager    *ui);
 
+static void descend_menu_set_always_show_image (GtkMenu *menu);
+
+static void set_additional_properties      (GtkUIManager    *ui);
+
+
 static void connect_proxy_cb               (GtkUIManager    *ui,
 					    GtkAction       *action,
 					    GtkWidget       *proxy,
@@ -175,6 +175,20 @@ static GtkActionEntry entries[] = {
 
 
 	/* Edit action entries. */
+	{ "EditUndo",
+	  GTK_STOCK_UNDO,
+	  N_("Undo"),
+	  "<control>Z",
+	  N_("Undo"),
+	  G_CALLBACK (gl_ui_cmd_edit_undo) },
+
+	{ "EditRedo",
+	  GTK_STOCK_REDO,
+	  N_("Redo"),
+	  "<shift><control>Z",
+	  N_("Redo"),
+	  G_CALLBACK (gl_ui_cmd_edit_redo) },
+
 	{ "EditCut",
 	  GTK_STOCK_CUT,
 	  N_("Cut"),
@@ -439,14 +453,6 @@ static GtkToggleActionEntry toggle_entries[] = {
 	  G_CALLBACK (gl_ui_cmd_view_property_bar_toggle),
 	  TRUE },
 
-	{ "ViewPropertyToolBarToolTips",
-	  NULL,
-	  N_("Show tooltips"),
-	  NULL,
-	  N_("Show tooltips for property toolbar"),
-	  G_CALLBACK (gl_ui_cmd_view_property_bar_tips_toggle),
-	  TRUE },
-
 	{ "ViewGrid",
 	  NULL,
 	  N_("Grid"),
@@ -484,22 +490,6 @@ static GtkToggleActionEntry ui_toggle_entries[] = {
 	  G_CALLBACK (view_ui_item_toggled_cb),
 	  TRUE },
 
-	{ "ViewMainToolBarToolTips",
-	  NULL,
-	  N_("Show tooltips"),
-	  NULL,
-	  N_("Show tooltips for main toolbar"),
-	  G_CALLBACK (view_ui_item_toggled_cb),
-	  TRUE },
-
-	{ "ViewDrawingToolBarToolTips",
-	  NULL,
-	  N_("Show tooltips"),
-	  NULL,
-	  N_("Show tooltips for drawing toolbar"),
-	  G_CALLBACK (view_ui_item_toggled_cb),
-	  TRUE },
-
 };
 static guint n_ui_toggle_entries = G_N_ELEMENTS (ui_toggle_entries);
 
@@ -524,6 +514,9 @@ static const gchar *ui_info =
 "			<menuitem action='FileQuit' />"
 "		</menu>"
 "		<menu action='EditMenu'>"
+"			<menuitem action='EditUndo' />"
+"			<menuitem action='EditRedo' />"
+"			<separator />"
 "			<menuitem action='EditCut' />"
 "			<menuitem action='EditCopy' />"
 "			<menuitem action='EditPaste' />"
@@ -539,16 +532,6 @@ static const gchar *ui_info =
 "			<menuitem action='ViewDrawingToolBar' />"
 "			<menuitem action='ViewPropertyToolBar' />"
 "			<separator />"
-"			<menu action='ViewMainToolBarMenu'>"
-"				<menuitem action='ViewMainToolBarToolTips' />"
-"			</menu>"
-"			<menu action='ViewDrawingToolBarMenu'>"
-"				<menuitem action='ViewDrawingToolBarToolTips' />"
-"			</menu>"
-"			<menu action='ViewPropertyToolBarMenu'>"
-"				<menuitem action='ViewPropertyToolBarToolTips' />"
-"			</menu>"
-"			<separator />"
 "			<menuitem action='ViewGrid' />"
 "			<menuitem action='ViewMarkup' />"
 "			<separator />"
@@ -672,9 +655,10 @@ static gchar* doc_verbs [] = {
 	"/ui/MenuBar/FileMenu/FileSaveAs",
 	"/ui/MenuBar/FileMenu/FilePrint",
 	"/ui/MenuBar/FileMenu/FileClose",
+	"/ui/MenuBar/EditMenu/EditUndo",
+	"/ui/MenuBar/EditMenu/EditRedo",
 	"/ui/MenuBar/EditMenu/EditCut",
 	"/ui/MenuBar/EditMenu/EditCopy",
-	"/ui/MenuBar/EditMenu/EditPaste",
 	"/ui/MenuBar/EditMenu/EditDelete",
 	"/ui/MenuBar/EditMenu/EditSelectAll",
 	"/ui/MenuBar/EditMenu/EditUnSelectAll",
@@ -716,6 +700,12 @@ static gchar* doc_modified_verbs [] = {
 	NULL
 };
 
+static gchar* paste_verbs [] = {
+	"/ui/MenuBar/EditMenu/EditPaste",
+
+	NULL
+};
+
 static gchar* selection_verbs [] = {
 	"/ui/MenuBar/EditMenu/EditCut",
 	"/ui/MenuBar/EditMenu/EditCopy",
@@ -775,6 +765,7 @@ gl_ui_new (glWindow *window)
 			  G_CALLBACK (disconnect_proxy_cb), window);
 
 	actions = gtk_action_group_new ("Actions");
+        gtk_action_group_set_translation_domain (actions, NULL);
 	gtk_action_group_add_actions (actions, entries, n_entries, GTK_WINDOW (window));
 	gtk_action_group_add_toggle_actions (actions, 
 					     toggle_entries, n_toggle_entries, 
@@ -807,13 +798,17 @@ gl_ui_new (glWindow *window)
 				   recent_menu);
 
 
+        set_additional_properties (ui);
+
 	gl_ui_util_set_verb_list_sensitive (ui, doc_verbs, FALSE);
+	gl_ui_util_set_verb_list_sensitive (ui, paste_verbs, FALSE);
 
 	gl_debug (DEBUG_UI, "END");
 
 	return ui;
 }
 
+
 /*****************************************************************************/
 /** Unref wrapper.                                                           */
 /*****************************************************************************/
@@ -827,6 +822,7 @@ gl_ui_unref (GtkUIManager *ui)
 	gl_debug (DEBUG_UI, "END");
 }
 
+
 /*****************************************************************************/
 /** Update all verbs of given UI component.                                  */
 /*****************************************************************************/
@@ -857,30 +853,18 @@ gl_ui_update_all (GtkUIManager *ui,
 				       !gl_view_is_zoom_min (view));
 
 	gl_ui_util_set_verb_list_sensitive (ui, selection_verbs,
-					    !gl_view_is_selection_empty (view));
+					    !gl_label_is_selection_empty (label));
 
 	gl_ui_util_set_verb_list_sensitive (ui, atomic_selection_verbs,
-					    gl_view_is_selection_atomic (view));
+					    gl_label_is_selection_atomic (label));
 
 	gl_ui_util_set_verb_list_sensitive (ui, multi_selection_verbs,
-					    !gl_view_is_selection_empty (view)
-					    && !gl_view_is_selection_atomic (view));
+					    !gl_label_is_selection_empty (label)
+					    && !gl_label_is_selection_atomic (label));
 
 	gl_debug (DEBUG_UI, "END");
 }
 
-/*****************************************************************************/
-/** Update all verbs of given UI component to "no document" state.           */
-/*****************************************************************************/
-void
-gl_ui_update_nodoc (GtkUIManager *ui)
-{
-	gl_debug (DEBUG_UI, "START");
-
-	gl_ui_util_set_verb_list_sensitive (ui, doc_verbs, FALSE);
-
-	gl_debug (DEBUG_UI, "END");
-}
 
 /*****************************************************************************/
 /** Update label modified verbs of given UI component.                       */
@@ -898,28 +882,40 @@ gl_ui_update_modified_verbs (GtkUIManager *ui,
 	gl_debug (DEBUG_UI, "END");
 }
 
+
 /*****************************************************************************/
 /** Update verbs associated with selection state of given UI component.      */
 /*****************************************************************************/
 void
 gl_ui_update_selection_verbs (GtkUIManager *ui,
-			      glView       *view)
+			      glView       *view,
+                              gboolean      has_focus)
 {
 	gl_debug (DEBUG_UI, "START");
 
-	gl_ui_util_set_verb_list_sensitive (ui, selection_verbs,
-					    !gl_view_is_selection_empty (view));
+        if ( has_focus )
+        {
+                gl_ui_util_set_verb_list_sensitive (ui, selection_verbs,
+                                                    !gl_label_is_selection_empty (view->label));
 
-	gl_ui_util_set_verb_list_sensitive (ui, atomic_selection_verbs,
-					    gl_view_is_selection_atomic (view));
+                gl_ui_util_set_verb_list_sensitive (ui, atomic_selection_verbs,
+                                                    gl_label_is_selection_atomic (view->label));
 
-	gl_ui_util_set_verb_list_sensitive (ui, multi_selection_verbs,
-					    !gl_view_is_selection_empty (view)
-					    && !gl_view_is_selection_atomic (view));
+                gl_ui_util_set_verb_list_sensitive (ui, multi_selection_verbs,
+                                                    !gl_label_is_selection_empty (view->label)
+                                                    && !gl_label_is_selection_atomic (view->label));
+        }
+        else
+        {
+                gl_ui_util_set_verb_list_sensitive (ui, selection_verbs, FALSE);
+                gl_ui_util_set_verb_list_sensitive (ui, atomic_selection_verbs, FALSE);
+                gl_ui_util_set_verb_list_sensitive (ui, multi_selection_verbs, FALSE);
+        }
 
 	gl_debug (DEBUG_UI, "END");
 }
 
+
 /*****************************************************************************/
 /** Update verbs associated with zoom level of given UI component.           */
 /*****************************************************************************/
@@ -937,6 +933,22 @@ gl_ui_update_zoom_verbs (GtkUIManager *ui,
 	gl_debug (DEBUG_UI, "END");
 }
 
+
+/*****************************************************************************/
+/** Update paste verbs of given UI component.                                */
+/*****************************************************************************/
+void
+gl_ui_update_paste_verbs (GtkUIManager      *ui,
+                          gboolean           can_paste)
+{
+	gl_debug (DEBUG_UI, "START");
+
+	gl_ui_util_set_verb_list_sensitive (ui, paste_verbs, can_paste);
+
+	gl_debug (DEBUG_UI, "END");
+}
+
+
 /*****************************************************************************/
 /** Update undo/redo verbs of given UI component.                            */
 /*****************************************************************************/
@@ -944,8 +956,26 @@ void
 gl_ui_update_undo_redo_verbs (GtkUIManager *ui,
 			      glLabel      *label)
 {
+        GtkWidget  *menu_item;
+        gchar      *description;
+        gchar      *menu_label;
+
 	gl_debug (DEBUG_UI, "START");
 
+        menu_item = gtk_ui_manager_get_widget (ui, "/MenuBar/EditMenu/EditUndo");
+        description = gl_label_get_undo_description (label);
+        menu_label = g_strdup_printf ("%s: %s", _("Undo"), description);
+        gtk_menu_item_set_label (GTK_MENU_ITEM (menu_item), menu_label);
+        g_free (menu_label);
+        g_free (description);
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/MenuBar/EditMenu/EditRedo");
+        description = gl_label_get_redo_description (label);
+        menu_label = g_strdup_printf ("%s: %s", _("Redo"), description);
+        gtk_menu_item_set_label (GTK_MENU_ITEM (menu_item), menu_label);
+        g_free (menu_label);
+        g_free (description);
+
 	gl_ui_util_set_verb_sensitive (ui, "/ui/MenuBar/EditMenu/EditUndo",
 				       gl_label_can_undo (label));
 
@@ -955,6 +985,7 @@ gl_ui_update_undo_redo_verbs (GtkUIManager *ui,
 	gl_debug (DEBUG_UI, "END");
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  View menu item toggled callback.                               */
 /*---------------------------------------------------------------------------*/
@@ -976,35 +1007,20 @@ view_ui_item_toggled_cb (GtkToggleAction *action,
 
 	if (strcmp (name, "ViewMainToolBar") == 0)
 	{
-		gl_prefs->main_toolbar_visible = state;
+                gl_prefs_model_set_main_toolbar_visible (gl_prefs, state);
 		set_app_main_toolbar_style (ui);
-		gl_prefs_model_save_settings (gl_prefs);
-	}
-
-	if (strcmp (name, "ViewMainToolBarToolTips") == 0)
-	{
-		gl_prefs->main_toolbar_view_tooltips = state;
-		set_app_main_toolbar_style (ui);
-		gl_prefs_model_save_settings (gl_prefs);
 	}
 
 	if (strcmp (name, "ViewDrawingToolBar") == 0)
 	{
-		gl_prefs->drawing_toolbar_visible = state;
+		gl_prefs_model_set_drawing_toolbar_visible (gl_prefs, state);
 		set_app_drawing_toolbar_style (ui);
-		gl_prefs_model_save_settings (gl_prefs);
-	}
-
-	if (strcmp (name, "ViewDrawingToolBarToolTips") == 0)
-	{
-		gl_prefs->drawing_toolbar_view_tooltips = state;
-		set_app_drawing_toolbar_style (ui);
-		gl_prefs_model_save_settings (gl_prefs);
 	}
 
 	gl_debug (DEBUG_UI, "");
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Set main toolbar style.                                        */
 /*---------------------------------------------------------------------------*/
@@ -1019,21 +1035,11 @@ set_app_main_toolbar_style (GtkUIManager *ui)
 			
 	/* Updated view menu */
 	gl_ui_util_set_verb_state (ui, "/ui/ViewMenu/ViewMainToolBar",
-				   gl_prefs->main_toolbar_visible);
+				   gl_prefs_model_get_main_toolbar_visible (gl_prefs));
 
-	gl_ui_util_set_verb_sensitive (ui, "/ui/ViewMenu/ViewMainToolBarToolTips",
-				       gl_prefs->main_toolbar_visible);
-
-	gl_ui_util_set_verb_state (ui, "/ui/ViewMenu/ViewMainToolBarToolTips",
-				   gl_prefs->main_toolbar_view_tooltips);
-
-	
 	toolbar = gtk_ui_manager_get_widget (ui, "/MainToolBar");
 
-	gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar),
-				  gl_prefs->main_toolbar_view_tooltips);
-
-	if (gl_prefs->main_toolbar_visible) {
+	if (gl_prefs_model_get_main_toolbar_visible (gl_prefs)) {
 		gtk_widget_show_all (toolbar);
 	} else {
 		gtk_widget_hide (toolbar);
@@ -1057,23 +1063,13 @@ set_app_drawing_toolbar_style (GtkUIManager *ui)
 			
 	/* Updated view menu */
 	gl_ui_util_set_verb_state (ui, "/ui/MenuBar/ViewMenu/ViewDrawingToolBar",
-				   gl_prefs->drawing_toolbar_visible);
+				   gl_prefs_model_get_drawing_toolbar_visible (gl_prefs));
 
-	gl_ui_util_set_verb_sensitive (ui, "/ui/MenuBar/ViewMenu/ViewDrawingToolBarToolTips",
-				       gl_prefs->drawing_toolbar_visible);
-
-	gl_ui_util_set_verb_state (ui, "/ui/MenuBar/ViewMenuDrawingToolBarToolTips",
-				   gl_prefs->drawing_toolbar_view_tooltips);
-
-	
 	toolbar = gtk_ui_manager_get_widget (ui, "/DrawingToolBar");
 
-	gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar),
-				  gl_prefs->drawing_toolbar_view_tooltips);
-
 	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
 
-	if (gl_prefs->drawing_toolbar_visible) {
+	if (gl_prefs_model_get_drawing_toolbar_visible (gl_prefs)) {
 		gtk_widget_show_all (toolbar);
 	} else {
 		gtk_widget_hide (toolbar);
@@ -1082,6 +1078,7 @@ set_app_drawing_toolbar_style (GtkUIManager *ui)
 	gl_debug (DEBUG_UI, "END");
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Set visibility of grid and markup.                             */
 /*---------------------------------------------------------------------------*/
@@ -1093,14 +1090,83 @@ set_view_style (GtkUIManager *ui)
 	g_return_if_fail (ui && GTK_IS_UI_MANAGER(ui));
 			
 	gl_ui_util_set_verb_state (ui, "/ui/MenuBar/ViewMenu/ViewGrid",
-				   gl_prefs->grid_visible);
+				   gl_prefs_model_get_grid_visible (gl_prefs));
 
 	gl_ui_util_set_verb_state (ui, "/ui/MenuBar/ViewMenu/ViewMarkup",
-				   gl_prefs->markup_visible);
+				   gl_prefs_model_get_markup_visible (gl_prefs));
 
 	gl_debug (DEBUG_UI, "END");
 }
 
+
+/*---------------------------------------------------------------------------*/
+/** PRIVATE.  Descend menu, set "always-show-image" for all image menu items.*/
+/*---------------------------------------------------------------------------*/
+static void
+descend_menu_set_always_show_image (GtkMenu *menu)
+{
+        GList       *children, *p;
+        GtkWidget   *submenu;
+        GtkWidget   *menu_item;
+
+        children = gtk_container_get_children (GTK_CONTAINER (menu));
+
+        for ( p = children; p != NULL; p = p->next )
+        {
+                menu_item = GTK_WIDGET (p->data);
+
+                submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+                if ( submenu )
+                {
+                        descend_menu_set_always_show_image (GTK_MENU (submenu));
+                }
+                else if ( GTK_IS_IMAGE_MENU_ITEM (menu_item) )
+                {
+                        g_object_set (menu_item, "always-show-image", TRUE, NULL);
+                }
+        }
+}
+
+
+/*---------------------------------------------------------------------------*/
+/** PRIVATE.  Set additional properties.                                     */
+/*---------------------------------------------------------------------------*/
+static void
+set_additional_properties (GtkUIManager *ui)
+{
+        GtkWidget  *menu;
+        GtkWidget  *menu_item;
+
+        /*
+         * Set "always-show-image" property for all Object menuitems.  This is
+         * necessary because, as of Gtk-2.18, images are not shown by default
+         * and you really need these visual cues for these menu items.
+         */
+        menu_item = gtk_ui_manager_get_widget (ui, "/MenuBar/ObjectsMenu/");
+        menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+        descend_menu_set_always_show_image (GTK_MENU (menu));
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/MenuBar/ObjectsMenu/ObjectsMergeProperties");
+        g_object_set (menu_item, "always-show-image", FALSE, NULL); /* Leave this one out. */
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/ContextMenu/ObjectsOrderMenu/");
+        menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+        descend_menu_set_always_show_image (GTK_MENU (menu));
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/ContextMenu/ObjectsRotateFlipMenu/");
+        menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+        descend_menu_set_always_show_image (GTK_MENU (menu));
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/ContextMenu/ObjectsAlignHorizMenu/");
+        menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+        descend_menu_set_always_show_image (GTK_MENU (menu));
+
+        menu_item = gtk_ui_manager_get_widget (ui, "/ContextMenu/ObjectsAlignVertMenu/");
+        menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (menu_item));
+        descend_menu_set_always_show_image (GTK_MENU (menu));
+}
+
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Connect proxy callback.                                        */
 /*---------------------------------------------------------------------------*/
@@ -1119,6 +1185,7 @@ connect_proxy_cb (GtkUIManager *ui,
 	}
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Disconnect proxy callback.                                     */
 /*---------------------------------------------------------------------------*/
@@ -1137,6 +1204,7 @@ disconnect_proxy_cb (GtkUIManager *ui,
 	}
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Menu item select callback.                                     */
 /*---------------------------------------------------------------------------*/
@@ -1162,6 +1230,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
 	}
 }
 
+
 /*---------------------------------------------------------------------------*/
 /** PRIVATE.  Menu item deselect callback.                                   */
 /*---------------------------------------------------------------------------*/
@@ -1176,3 +1245,13 @@ menu_item_deselect_cb (GtkMenuItem *proxy,
 			   window->menu_tips_context_id);
 }
 
+
+
+/*
+ * Local Variables:       -- emacs
+ * mode: C                -- emacs
+ * c-basic-offset: 8      -- emacs
+ * tab-width: 8           -- emacs
+ * indent-tabs-mode: nil  -- emacs
+ * End:                   -- emacs
+ */
